@@ -1,6 +1,6 @@
 package Win32::Scsv;
-$Win32::Scsv::VERSION = '0.40';
-use strict;
+$Win32::Scsv::VERSION = '0.41';
+use 5.026;
 use warnings;
 
 =head1 NAME
